package cn.sh.stc.sict.cloud.common.core.util;

import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpResponse;
import cn.hutool.json.JSONUtil;
import cn.sh.stc.sict.cloud.common.core.dto.WDUserCardInfo;
import cn.sh.stc.sict.cloud.common.core.dto.WDUserInfo;
import lombok.experimental.UtilityClass;
import lombok.extern.slf4j.Slf4j;

import java.util.List;

/**
 * 随申办工具类
 */
@Slf4j
@UtilityClass
public class SsbUtil {
    // 外网测试地址   https://ffyjs.hpwjsns.org.cn:9071/
    // private final static String USER_URL = "https://ffyjs.hpwjsns.org.cn:9071/fdapp/api/account/v1/token/info";
    // private final static String CARD_URL = "https://ffyjs.hpwjsns.org.cn:9071/fdapp/api/account/v1/user/cards";
    // 内网线上地址   http://173.18.1.97:9071/fdapp/
    private final static String USER_URL = "http://173.18.1.97:9071/fdapp/api/account/v1/token/info";
    private final static String CARD_URL = "http://173.18.1.97:9071/fdapp/api/account/v1/user/cards";

    /**
     * 获取用户信息
     *
     * @param token
     * @return
     */
    public WDUserInfo getUserInfo(String token) {
        try {
            HttpResponse response = HttpRequest.get(USER_URL)
                    .header("backdoor", "1")
                    .header("access-token", token)
                    .execute();
            if (response.getStatus() != 200) {
                log.error("随申办token获取用户信息异常-1");
                return null;
            }
            return JSONUtil.toBean(response.body(), WDUserInfo.class);
        } catch (Exception ex) {
            log.error("随申办token获取用户信息异-2！");
            log.error(ex.getMessage(), ex);
            return null;
        }
    }

    /**
     * 获取用户绑卡信息
     *
     * @param token
     * @return
     */
    public List<WDUserCardInfo> getUserCardInfoList(String token) {
        try {
            HttpResponse response = HttpRequest.get(CARD_URL)
                    .header("backdoor", "1")
                    .header("access-token", token)
                    .execute();
            if (response.getStatus() != 200) {
                log.error("随申办token获取绑卡信息异常-1");
                return null;
            }
            return JSONUtil.toList(JSONUtil.parseArray(response.body()), WDUserCardInfo.class);
        } catch (Exception ex) {
            log.error("随申办token获取绑卡信息异-2！");
            log.error(ex.getMessage(), ex);
            return null;
        }
    }
}
