package cn.sh.stc.sict.cloud.common.core.util;

import cn.hutool.core.util.StrUtil;
import cn.sh.stc.sict.cloud.common.core.constant.RedisCacheConstant;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.data.redis.core.StringRedisTemplate;

import java.util.concurrent.TimeUnit;

/**
 * @Description 验证码校验工具类
 * @Author
 * @Date
 */
public class ValidateCodeUtil {

    /**
     * 过期时间/s
     */
    private final static Long EXPIRE_TIME_SECOND = 120L;

    /**
     * 从redis取出验证码并验证
     * type : 0-登录 1-注册
     */
    public static boolean validateCode(StringRedisTemplate redisTemplate, String phone, String code, Byte type) {
        String key = RedisCacheConstant.SICT_PHONE_CODE_KEY + ":" + type + ":" + phone;
        if (!redisTemplate.hasKey(key)) {
            return false;
        }
        Object codeObj = redisTemplate.opsForValue().get(key);

        if (codeObj == null) {
            return false;
        }
        String savedCode = codeObj.toString();
        if (StrUtil.isBlank(savedCode)) {
            redisTemplate.delete(key);
            return false;
        }
        if (!StrUtil.equals(savedCode, code)) {
            return false;
        }
        redisTemplate.delete(key);
        return true;
    }

    public static void saveCode(RedisTemplate redisTemplate, String phone, String code, Byte type) {
        String key = RedisCacheConstant.SICT_PHONE_CODE_KEY + ":" + type + ":" + phone;
        redisTemplate.opsForValue().set(key, code, EXPIRE_TIME_SECOND, TimeUnit.SECONDS);
    }

    public static boolean hasPhoneKey(RedisTemplate redisTemplate, String phone, Byte type) {
        String key = RedisCacheConstant.SICT_PHONE_CODE_KEY + ":" + type + ":" + phone;
        if (redisTemplate.hasKey(key)) {
            return true;
        }
        return false;
    }
}
