package cn.sh.stc.sict.cloud.common.core.util;

import cn.hutool.core.collection.ListUtil;
import cn.hutool.core.convert.Convert;
import cn.hutool.http.HttpRequest;
import cn.hutool.http.HttpResponse;
import cn.hutool.json.JSONUtil;
import cn.sh.stc.sict.cloud.common.core.constant.enums.ZzUserApiEnum;
import cn.sh.stc.sict.cloud.common.core.dto.WOAWDUserInfo;
import cn.sh.stc.sict.cloud.common.core.dto.WOAZzUserInfo;
import cn.sh.stc.sict.cloud.common.core.dto.XSZYUserInfo;
import lombok.experimental.UtilityClass;
import lombok.extern.slf4j.Slf4j;
import ngari.openapi.Client;
import ngari.openapi.JSONResponseBean;
import ngari.openapi.Request;
import ngari.openapi.Response;

/**
 * 医院公众号工具类
 * <p>
 * 注意事项：
 * 1.医院编码是否传递
 * 2.手机号必须有，作为用户身份的唯一标识
 */
@Slf4j
@UtilityClass
public class WoaUtil {

    /**
     * 香山中医医院公众号用户信息获取接口地址（纳里）
     */
    private final static String WOA_XSZY_URL = "https://openapi.ngarihealth.com";
    private final static String WOA_XSZY_GATEWAY_URL = "/openapi/gateway";
    /**
     * 内网代理请求地址
     */
    private final static String WOA_XSZY_PROXY_PASS_URL = "http://30.30.5.74:9988/woa/xszy";
    /**
     * 获取用户信息请求地址
     */
    private final static String WOA_XSZY_USER_INFO_API_URL = WOA_XSZY_PROXY_PASS_URL + WOA_XSZY_GATEWAY_URL;

    /**
     * 接口授权信息
     */
    private final static String APP_KEY = "ngari635f7f4b0e980e63";
    private final static String APP_SECRET = "0e980e634196fcde";

    /**
     * 获取用户信息服务ID
     */
    private final static String SERVICE_ID = "openapi.authenticationService";
    /**
     * 获取用户信息方法
     */
    private final static String METHOD = "apiGetUserInfo";
    /**
     * 响应头请求唯一ID
     */
    private final static String RESPONSE_HEADER_REQUEST_ID = "X-Ca-RequestId";

    /**
     * 获取用户信息
     *
     * @param ngCode 纳里授权码
     * @return
     */
    public XSZYUserInfo getXszyUserInfo(String ngCode) {

        //如果开启加密，则必填
        String encodingAesKey = "";
        Client client = new Client(WOA_XSZY_USER_INFO_API_URL, APP_KEY, APP_SECRET, encodingAesKey);

        try {
            // 入参说明[授权码，是否回调，拓展参数]
            Request request = new Request(SERVICE_ID, METHOD, ListUtil.toList(ngCode, false, null));
            Response response = client.execute(request);
            if (response.isSuccess()) {
                JSONResponseBean result = response.getJsonResponseBean();
                XSZYUserInfo xszyUserInfo = Convert.convert(XSZYUserInfo.class, result.getBody());
                return xszyUserInfo;
            } else {
                log.error("香山中医医院公众号token获取用户信息异常-1，requestId = [{}]，caError = [{}]，error = [{}]", response.getHeader(RESPONSE_HEADER_REQUEST_ID), response.getCaErrorMsg(), response.getErrorMessage());
                log.error(JSONUtil.toJsonStr(response));
                return null;
            }
        } catch (Exception ex) {
            log.error("香山中医医院公众号token获取用户信息异-2！");
            log.error(ex.getMessage(), ex);
            return null;
        }
    }

    /**
     * 中智公众号用户url
     * 打浦桥，外滩，小东门，老西门，豫园，五里桥，淮海，瑞二
     */
    private final static String WOA_ZZ_PROXY_PASS_URL = "http://30.30.5.74:9988/woa/zz";
    // private final static String WOA_ZZ_PROXY_PASS_URL = "https://booking.hpdapuqiao.com";
    private final static String ZZ_USER_INFO_API_URL = "/api/Other/GetPerson";

    //private final static String WOA_WD_PROXY_PASS_URL = "https://wxgzh.shjyhpfy.com/api/hosservice/visit/GetUserInfoByToken";
    private final static String WOA_WD_PROXY_PASS_URL = "http://30.30.5.74:9988/woa/wd";
    private final static String WOA_WD_USER_INFO_URL = WOA_WD_PROXY_PASS_URL + "/api/hosservice/visit/GetUserInfoByToken";

    public WOAZzUserInfo getZzUserInfo(String appid, String accessToken) {
        try {
            ZzUserApiEnum zzUserApiEnum = ZzUserApiEnum.find(appid);
            String url = WOA_ZZ_PROXY_PASS_URL + zzUserApiEnum.getRelativePath() + ZZ_USER_INFO_API_URL;
            HttpResponse response = HttpRequest.get(url)
                    .header("access-token", accessToken)
                    .execute();
            if (response.getStatus() != 200) {
                log.error("中智获取用户信息异常-1");
                return null;
            }
            log.error("response = {}", JSONUtil.toJsonStr(response.body()));
            return JSONUtil.toBean(response.body(), WOAZzUserInfo.class);
        } catch (Exception ex) {
            log.error("中智token获取用户信息异-2！");
            log.error(ex.getMessage(), ex);
            return null;
        }
    }

    public WOAWDUserInfo getWoaWDUserInfo(String accessToken) {
        try {
            HttpResponse response = HttpRequest.get(WOA_WD_USER_INFO_URL)
                    .header("access-token", accessToken)
                    .execute();
            if (response.getStatus() != 200) {
                log.error("万达公众号获取用户信息异常-1");
                return null;
            }
            return JSONUtil.toBean(response.body(), WOAWDUserInfo.class);
        } catch (Exception ex) {
            log.error("万达公众号token获取用户信息异-2！");
            log.error(ex.getMessage(), ex);
            return null;
        }

    }

}
